import os
import logging
import tempfile
from contextlib import contextmanager
from textwrap import dedent

from utility import (
    ensure_dir,
    temp_dir,
    )
import assess_autoload_credentials as aac

log = logging.getLogger("credential_utility")


def write_aws_config_file(user, tmp_dir, access_key, secret_key):
    """Write aws credentials file to tmp_dir

    :return: String path of created credentials file.

    """
    config_dir = os.path.join(tmp_dir, '.aws')
    config_file = os.path.join(config_dir, 'credentials')
    ensure_dir(config_dir)

    config_contents = dedent("""\
    [{}]
    aws_access_key_id={}
    aws_secret_access_key={}
    """.format(user, access_key, secret_key))

    with open(config_file, 'w') as f:
        f.write(config_contents)

    return config_file


def client_credentials_to_details(client):
    """Convert the credentials in the client to details."""
    provider = client.env.provider
    log.info("provider: {}".format(provider))
    cloud_name = client.env.get_cloud()
    log.info("cloud_name: {}".format(cloud_name))
    credentials = client.env.get_cloud_credentials()
    if 'ec2' == provider:
        return {'secret_key': credentials['secret-key'],
                'access_key': credentials['access-key'],
                }
    if 'gce' == provider:
        aac.gce_prepare_for_load()
        return {'client_id': credentials['client-id'],
                'client_email': credentials['client-email'],
                'private_key': credentials['private-key'],
                }
    if 'openstack' == provider:
        os_cloud = client.env.clouds['clouds'][cloud_name]
        return {'os_tenant_name': credentials['tenant-name'],
                'os_password': credentials['password'],
                'os_region_name': client.env.get_region(),
                'os_auth_url': os_cloud['endpoint'],
                }


@contextmanager
def begin_test(client_base):
    client = client_base.clone(env=client_base.env.clone())
    with temp_dir() as tmp_dir:
        tmp_juju_home = tempfile.mkdtemp(dir=tmp_dir)
        tmp_scratch_dir = tempfile.mkdtemp(dir=tmp_dir)
        client.env.juju_home = tmp_juju_home
        client.env.load_yaml()
        with aac.fake_juju_data():
            yield client, tmp_scratch_dir
